==> openshift-model-monitoring-6.0.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/RemoteWriteSpecFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface RemoteWriteSpecFluent<A extends RemoteWriteSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAuthorization instead.
   * @return The buildable object.
   */
  @Deprecated
  public Authorization getAuthorization();
  public Authorization buildAuthorization();
  public A withAuthorization(Authorization authorization);
  public Boolean hasAuthorization();
  public RemoteWriteSpecFluent.AuthorizationNested<A> withNewAuthorization();
  public RemoteWriteSpecFluent.AuthorizationNested<A> withNewAuthorizationLike(Authorization item);
  public RemoteWriteSpecFluent.AuthorizationNested<A> editAuthorization();
  public RemoteWriteSpecFluent.AuthorizationNested<A> editOrNewAuthorization();
  public RemoteWriteSpecFluent.AuthorizationNested<A> editOrNewAuthorizationLike(Authorization item);
  
  /**
   * This method has been deprecated, please use method buildBasicAuth instead.
   * @return The buildable object.
   */
  @Deprecated
  public BasicAuth getBasicAuth();
  public BasicAuth buildBasicAuth();
  public A withBasicAuth(BasicAuth basicAuth);
  public Boolean hasBasicAuth();
  public RemoteWriteSpecFluent.BasicAuthNested<A> withNewBasicAuth();
  public RemoteWriteSpecFluent.BasicAuthNested<A> withNewBasicAuthLike(BasicAuth item);
  public RemoteWriteSpecFluent.BasicAuthNested<A> editBasicAuth();
  public RemoteWriteSpecFluent.BasicAuthNested<A> editOrNewBasicAuth();
  public RemoteWriteSpecFluent.BasicAuthNested<A> editOrNewBasicAuthLike(BasicAuth item);
  public String getBearerToken();
  public A withBearerToken(String bearerToken);
  public Boolean hasBearerToken();
  public String getBearerTokenFile();
  public A withBearerTokenFile(String bearerTokenFile);
  public Boolean hasBearerTokenFile();
  public A addToHeaders(String key,String value);
  public A addToHeaders(Map<String,String> map);
  public A removeFromHeaders(String key);
  public A removeFromHeaders(Map<String,String> map);
  public Map<String,String> getHeaders();
  public <K,V>A withHeaders(Map<String,String> headers);
  public Boolean hasHeaders();
  
  /**
   * This method has been deprecated, please use method buildMetadataConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetadataConfig getMetadataConfig();
  public MetadataConfig buildMetadataConfig();
  public A withMetadataConfig(MetadataConfig metadataConfig);
  public Boolean hasMetadataConfig();
  public A withNewMetadataConfig(Boolean send,String sendInterval);
  public RemoteWriteSpecFluent.MetadataConfigNested<A> withNewMetadataConfig();
  public RemoteWriteSpecFluent.MetadataConfigNested<A> withNewMetadataConfigLike(MetadataConfig item);
  public RemoteWriteSpecFluent.MetadataConfigNested<A> editMetadataConfig();
  public RemoteWriteSpecFluent.MetadataConfigNested<A> editOrNewMetadataConfig();
  public RemoteWriteSpecFluent.MetadataConfigNested<A> editOrNewMetadataConfigLike(MetadataConfig item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  
  /**
   * This method has been deprecated, please use method buildOauth2 instead.
   * @return The buildable object.
   */
  @Deprecated
  public OAuth2 getOauth2();
  public OAuth2 buildOauth2();
  public A withOauth2(OAuth2 oauth2);
  public Boolean hasOauth2();
  public RemoteWriteSpecFluent.Oauth2Nested<A> withNewOauth2();
  public RemoteWriteSpecFluent.Oauth2Nested<A> withNewOauth2Like(OAuth2 item);
  public RemoteWriteSpecFluent.Oauth2Nested<A> editOauth2();
  public RemoteWriteSpecFluent.Oauth2Nested<A> editOrNewOauth2();
  public RemoteWriteSpecFluent.Oauth2Nested<A> editOrNewOauth2Like(OAuth2 item);
  public String getProxyUrl();
  public A withProxyUrl(String proxyUrl);
  public Boolean hasProxyUrl();
  
  /**
   * This method has been deprecated, please use method buildQueueConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public QueueConfig getQueueConfig();
  public QueueConfig buildQueueConfig();
  public A withQueueConfig(QueueConfig queueConfig);
  public Boolean hasQueueConfig();
  public RemoteWriteSpecFluent.QueueConfigNested<A> withNewQueueConfig();
  public RemoteWriteSpecFluent.QueueConfigNested<A> withNewQueueConfigLike(QueueConfig item);
  public RemoteWriteSpecFluent.QueueConfigNested<A> editQueueConfig();
  public RemoteWriteSpecFluent.QueueConfigNested<A> editOrNewQueueConfig();
  public RemoteWriteSpecFluent.QueueConfigNested<A> editOrNewQueueConfigLike(QueueConfig item);
  public String getRemoteTimeout();
  public A withRemoteTimeout(String remoteTimeout);
  public Boolean hasRemoteTimeout();
  public Boolean getSendExemplars();
  public A withSendExemplars(Boolean sendExemplars);
  public Boolean hasSendExemplars();
  
  /**
   * This method has been deprecated, please use method buildSigv4 instead.
   * @return The buildable object.
   */
  @Deprecated
  public Sigv4 getSigv4();
  public Sigv4 buildSigv4();
  public A withSigv4(Sigv4 sigv4);
  public Boolean hasSigv4();
  public RemoteWriteSpecFluent.Sigv4Nested<A> withNewSigv4();
  public RemoteWriteSpecFluent.Sigv4Nested<A> withNewSigv4Like(Sigv4 item);
  public RemoteWriteSpecFluent.Sigv4Nested<A> editSigv4();
  public RemoteWriteSpecFluent.Sigv4Nested<A> editOrNewSigv4();
  public RemoteWriteSpecFluent.Sigv4Nested<A> editOrNewSigv4Like(Sigv4 item);
  
  /**
   * This method has been deprecated, please use method buildTlsConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public TLSConfig getTlsConfig();
  public TLSConfig buildTlsConfig();
  public A withTlsConfig(TLSConfig tlsConfig);
  public Boolean hasTlsConfig();
  public RemoteWriteSpecFluent.TlsConfigNested<A> withNewTlsConfig();
  public RemoteWriteSpecFluent.TlsConfigNested<A> withNewTlsConfigLike(TLSConfig item);
  public RemoteWriteSpecFluent.TlsConfigNested<A> editTlsConfig();
  public RemoteWriteSpecFluent.TlsConfigNested<A> editOrNewTlsConfig();
  public RemoteWriteSpecFluent.TlsConfigNested<A> editOrNewTlsConfigLike(TLSConfig item);
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public A addToWriteRelabelConfigs(Integer index,RelabelConfig item);
  public A setToWriteRelabelConfigs(Integer index,RelabelConfig item);
  public A addToWriteRelabelConfigs(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig... items);
  public A addAllToWriteRelabelConfigs(Collection<RelabelConfig> items);
  public A removeFromWriteRelabelConfigs(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig... items);
  public A removeAllFromWriteRelabelConfigs(Collection<RelabelConfig> items);
  public A removeMatchingFromWriteRelabelConfigs(Predicate<RelabelConfigBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildWriteRelabelConfigs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RelabelConfig> getWriteRelabelConfigs();
  public List<RelabelConfig> buildWriteRelabelConfigs();
  public RelabelConfig buildWriteRelabelConfig(Integer index);
  public RelabelConfig buildFirstWriteRelabelConfig();
  public RelabelConfig buildLastWriteRelabelConfig();
  public RelabelConfig buildMatchingWriteRelabelConfig(Predicate<RelabelConfigBuilder> predicate);
  public Boolean hasMatchingWriteRelabelConfig(Predicate<RelabelConfigBuilder> predicate);
  public A withWriteRelabelConfigs(List<RelabelConfig> writeRelabelConfigs);
  public A withWriteRelabelConfigs(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig... writeRelabelConfigs);
  public Boolean hasWriteRelabelConfigs();
  public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> addNewWriteRelabelConfig();
  public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> addNewWriteRelabelConfigLike(RelabelConfig item);
  public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> setNewWriteRelabelConfigLike(Integer index,RelabelConfig item);
  public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> editWriteRelabelConfig(Integer index);
  public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> editFirstWriteRelabelConfig();
  public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> editLastWriteRelabelConfig();
  public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> editMatchingWriteRelabelConfig(Predicate<RelabelConfigBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withSendExemplars();
  public interface AuthorizationNested<N> extends Nested<N>,AuthorizationFluent<RemoteWriteSpecFluent.AuthorizationNested<N>>{
    public N and();
    public N endAuthorization();
    
  }
  public interface BasicAuthNested<N> extends Nested<N>,BasicAuthFluent<RemoteWriteSpecFluent.BasicAuthNested<N>>{
    public N and();
    public N endBasicAuth();
    
  }
  public interface MetadataConfigNested<N> extends Nested<N>,MetadataConfigFluent<RemoteWriteSpecFluent.MetadataConfigNested<N>>{
    public N and();
    public N endMetadataConfig();
    
  }
  public interface Oauth2Nested<N> extends Nested<N>,OAuth2Fluent<RemoteWriteSpecFluent.Oauth2Nested<N>>{
    public N and();
    public N endOauth2();
    
  }
  public interface QueueConfigNested<N> extends Nested<N>,QueueConfigFluent<RemoteWriteSpecFluent.QueueConfigNested<N>>{
    public N and();
    public N endQueueConfig();
    
  }
  public interface Sigv4Nested<N> extends Nested<N>,Sigv4Fluent<RemoteWriteSpecFluent.Sigv4Nested<N>>{
    public N and();
    public N endSigv4();
    
  }
  public interface TlsConfigNested<N> extends Nested<N>,TLSConfigFluent<RemoteWriteSpecFluent.TlsConfigNested<N>>{
    public N and();
    public N endTlsConfig();
    
  }
  public interface WriteRelabelConfigsNested<N> extends Nested<N>,RelabelConfigFluent<RemoteWriteSpecFluent.WriteRelabelConfigsNested<N>>{
    public N and();
    public N endWriteRelabelConfig();
    
  }
  
}

==> openshift-model-monitoring-6.7.2-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/RemoteWriteSpecFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface RemoteWriteSpecFluent<A extends RemoteWriteSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAuthorization instead.
   * @return The buildable object.
   */
  @Deprecated
  public Authorization getAuthorization();
  public Authorization buildAuthorization();
  public A withAuthorization(Authorization authorization);
  public Boolean hasAuthorization();
  public RemoteWriteSpecFluent.AuthorizationNested<A> withNewAuthorization();
  public RemoteWriteSpecFluent.AuthorizationNested<A> withNewAuthorizationLike(Authorization item);
  public RemoteWriteSpecFluent.AuthorizationNested<A> editAuthorization();
  public RemoteWriteSpecFluent.AuthorizationNested<A> editOrNewAuthorization();
  public RemoteWriteSpecFluent.AuthorizationNested<A> editOrNewAuthorizationLike(Authorization item);
  
  /**
   * This method has been deprecated, please use method buildBasicAuth instead.
   * @return The buildable object.
   */
  @Deprecated
  public BasicAuth getBasicAuth();
  public BasicAuth buildBasicAuth();
  public A withBasicAuth(BasicAuth basicAuth);
  public Boolean hasBasicAuth();
  public RemoteWriteSpecFluent.BasicAuthNested<A> withNewBasicAuth();
  public RemoteWriteSpecFluent.BasicAuthNested<A> withNewBasicAuthLike(BasicAuth item);
  public RemoteWriteSpecFluent.BasicAuthNested<A> editBasicAuth();
  public RemoteWriteSpecFluent.BasicAuthNested<A> editOrNewBasicAuth();
  public RemoteWriteSpecFluent.BasicAuthNested<A> editOrNewBasicAuthLike(BasicAuth item);
  public String getBearerToken();
  public A withBearerToken(String bearerToken);
  public Boolean hasBearerToken();
  public String getBearerTokenFile();
  public A withBearerTokenFile(String bearerTokenFile);
  public Boolean hasBearerTokenFile();
  public A addToHeaders(String key,String value);
  public A addToHeaders(Map<String,String> map);
  public A removeFromHeaders(String key);
  public A removeFromHeaders(Map<String,String> map);
  public Map<String,String> getHeaders();
  public <K,V>A withHeaders(Map<String,String> headers);
  public Boolean hasHeaders();
  
  /**
   * This method has been deprecated, please use method buildMetadataConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetadataConfig getMetadataConfig();
  public MetadataConfig buildMetadataConfig();
  public A withMetadataConfig(MetadataConfig metadataConfig);
  public Boolean hasMetadataConfig();
  public A withNewMetadataConfig(Boolean send,String sendInterval);
  public RemoteWriteSpecFluent.MetadataConfigNested<A> withNewMetadataConfig();
  public RemoteWriteSpecFluent.MetadataConfigNested<A> withNewMetadataConfigLike(MetadataConfig item);
  public RemoteWriteSpecFluent.MetadataConfigNested<A> editMetadataConfig();
  public RemoteWriteSpecFluent.MetadataConfigNested<A> editOrNewMetadataConfig();
  public RemoteWriteSpecFluent.MetadataConfigNested<A> editOrNewMetadataConfigLike(MetadataConfig item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  
  /**
   * This method has been deprecated, please use method buildOauth2 instead.
   * @return The buildable object.
   */
  @Deprecated
  public OAuth2 getOauth2();
  public OAuth2 buildOauth2();
  public A withOauth2(OAuth2 oauth2);
  public Boolean hasOauth2();
  public RemoteWriteSpecFluent.Oauth2Nested<A> withNewOauth2();
  public RemoteWriteSpecFluent.Oauth2Nested<A> withNewOauth2Like(OAuth2 item);
  public RemoteWriteSpecFluent.Oauth2Nested<A> editOauth2();
  public RemoteWriteSpecFluent.Oauth2Nested<A> editOrNewOauth2();
  public RemoteWriteSpecFluent.Oauth2Nested<A> editOrNewOauth2Like(OAuth2 item);
  public String getProxyUrl();
  public A withProxyUrl(String proxyUrl);
  public Boolean hasProxyUrl();
  
  /**
   * This method has been deprecated, please use method buildQueueConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public QueueConfig getQueueConfig();
  public QueueConfig buildQueueConfig();
  public A withQueueConfig(QueueConfig queueConfig);
  public Boolean hasQueueConfig();
  public RemoteWriteSpecFluent.QueueConfigNested<A> withNewQueueConfig();
  public RemoteWriteSpecFluent.QueueConfigNested<A> withNewQueueConfigLike(QueueConfig item);
  public RemoteWriteSpecFluent.QueueConfigNested<A> editQueueConfig();
  public RemoteWriteSpecFluent.QueueConfigNested<A> editOrNewQueueConfig();
  public RemoteWriteSpecFluent.QueueConfigNested<A> editOrNewQueueConfigLike(QueueConfig item);
  public String getRemoteTimeout();
  public A withRemoteTimeout(String remoteTimeout);
  public Boolean hasRemoteTimeout();
  public Boolean getSendExemplars();
  public A withSendExemplars(Boolean sendExemplars);
  public Boolean hasSendExemplars();
  
  /**
   * This method has been deprecated, please use method buildSigv4 instead.
   * @return The buildable object.
   */
  @Deprecated
  public Sigv4 getSigv4();
  public Sigv4 buildSigv4();
  public A withSigv4(Sigv4 sigv4);
  public Boolean hasSigv4();
  public RemoteWriteSpecFluent.Sigv4Nested<A> withNewSigv4();
  public RemoteWriteSpecFluent.Sigv4Nested<A> withNewSigv4Like(Sigv4 item);
  public RemoteWriteSpecFluent.Sigv4Nested<A> editSigv4();
  public RemoteWriteSpecFluent.Sigv4Nested<A> editOrNewSigv4();
  public RemoteWriteSpecFluent.Sigv4Nested<A> editOrNewSigv4Like(Sigv4 item);
  
  /**
   * This method has been deprecated, please use method buildTlsConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public TLSConfig getTlsConfig();
  public TLSConfig buildTlsConfig();
  public A withTlsConfig(TLSConfig tlsConfig);
  public Boolean hasTlsConfig();
  public RemoteWriteSpecFluent.TlsConfigNested<A> withNewTlsConfig();
  public RemoteWriteSpecFluent.TlsConfigNested<A> withNewTlsConfigLike(TLSConfig item);
  public RemoteWriteSpecFluent.TlsConfigNested<A> editTlsConfig();
  public RemoteWriteSpecFluent.TlsConfigNested<A> editOrNewTlsConfig();
  public RemoteWriteSpecFluent.TlsConfigNested<A> editOrNewTlsConfigLike(TLSConfig item);
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public A addToWriteRelabelConfigs(int index,RelabelConfig item);
  public A setToWriteRelabelConfigs(int index,RelabelConfig item);
  public A addToWriteRelabelConfigs(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig... items);
  public A addAllToWriteRelabelConfigs(Collection<RelabelConfig> items);
  public A removeFromWriteRelabelConfigs(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig... items);
  public A removeAllFromWriteRelabelConfigs(Collection<RelabelConfig> items);
  public A removeMatchingFromWriteRelabelConfigs(Predicate<RelabelConfigBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildWriteRelabelConfigs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RelabelConfig> getWriteRelabelConfigs();
  public List<RelabelConfig> buildWriteRelabelConfigs();
  public RelabelConfig buildWriteRelabelConfig(int index);
  public RelabelConfig buildFirstWriteRelabelConfig();
  public RelabelConfig buildLastWriteRelabelConfig();
  public RelabelConfig buildMatchingWriteRelabelConfig(Predicate<RelabelConfigBuilder> predicate);
  public Boolean hasMatchingWriteRelabelConfig(Predicate<RelabelConfigBuilder> predicate);
  public A withWriteRelabelConfigs(List<RelabelConfig> writeRelabelConfigs);
  public A withWriteRelabelConfigs(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig... writeRelabelConfigs);
  public Boolean hasWriteRelabelConfigs();
  public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> addNewWriteRelabelConfig();
  public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> addNewWriteRelabelConfigLike(RelabelConfig item);
  public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> setNewWriteRelabelConfigLike(int index,RelabelConfig item);
  public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> editWriteRelabelConfig(int index);
  public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> editFirstWriteRelabelConfig();
  public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> editLastWriteRelabelConfig();
  public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> editMatchingWriteRelabelConfig(Predicate<RelabelConfigBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withSendExemplars();
  public interface AuthorizationNested<N> extends Nested<N>,AuthorizationFluent<RemoteWriteSpecFluent.AuthorizationNested<N>>{
    public N and();
    public N endAuthorization();
    
  }
  public interface BasicAuthNested<N> extends Nested<N>,BasicAuthFluent<RemoteWriteSpecFluent.BasicAuthNested<N>>{
    public N and();
    public N endBasicAuth();
    
  }
  public interface MetadataConfigNested<N> extends Nested<N>,MetadataConfigFluent<RemoteWriteSpecFluent.MetadataConfigNested<N>>{
    public N and();
    public N endMetadataConfig();
    
  }
  public interface Oauth2Nested<N> extends Nested<N>,OAuth2Fluent<RemoteWriteSpecFluent.Oauth2Nested<N>>{
    public N and();
    public N endOauth2();
    
  }
  public interface QueueConfigNested<N> extends Nested<N>,QueueConfigFluent<RemoteWriteSpecFluent.QueueConfigNested<N>>{
    public N and();
    public N endQueueConfig();
    
  }
  public interface Sigv4Nested<N> extends Nested<N>,Sigv4Fluent<RemoteWriteSpecFluent.Sigv4Nested<N>>{
    public N and();
    public N endSigv4();
    
  }
  public interface TlsConfigNested<N> extends Nested<N>,TLSConfigFluent<RemoteWriteSpecFluent.TlsConfigNested<N>>{
    public N and();
    public N endTlsConfig();
    
  }
  public interface WriteRelabelConfigsNested<N> extends Nested<N>,RelabelConfigFluent<RemoteWriteSpecFluent.WriteRelabelConfigsNested<N>>{
    public N and();
    public N endWriteRelabelConfig();
    
  }
  
}
